package common.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

public abstract class NBTBase {
	protected static NBTBase createNewByType(byte id) {
		switch(id) {
			case 0:
				return new NBTTagEnd();
			case 1:
				return new NBTTagByte();
			case 2:
				return new NBTTagShort();
			case 3:
				return new NBTTagInt();
			case 4:
				return new NBTTagLong();
			case 5:
				return new NBTTagFloat();
			case 6:
				return new NBTTagDouble();
			case 7:
				return new NBTTagByteArray();
			case 8:
				return new NBTTagString();
			case 9:
				return new NBTTagStringList();
			case 10:
				return new NBTTagCompound();
			case 11:
				return new NBTTagIntArray();
			case 12:
				return new NBTTagTagList();
			case 13:
				return new NBTTagFloatList();
			case 14:
				return new NBTTagDoubleList();
			case 15:
				return new NBTTagIntArrayList();
			default:
				return null;
		}
	}

	abstract void write(DataOutput output) throws IOException;
	abstract void read(DataInput input, int depth, SizeTracker tracker) throws IOException;
	public abstract String toString();
	public abstract byte getId();
	public abstract NBTBase copy();

	public boolean equals(Object other) {
		return other instanceof NBTBase && this.getId() == ((NBTBase)other).getId();
	}

	public int hashCode() {
		return this.getId();
	}
}
