package common.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Arrays;

class NBTTagByteArray extends NBTBase {
	private byte[] data;

	NBTTagByteArray() {
	}

	public NBTTagByteArray(byte[] data) {
		this.data = data;
	}

	void write(DataOutput output) throws IOException {
		output.writeInt(this.data.length);
		output.write(this.data);
	}

	void read(DataInput input, int depth, SizeTracker tracker) throws IOException {
		tracker.read(24);
		int len = input.readInt();
		tracker.read(len);
		this.data = new byte[len];
		input.readFully(this.data);
	}

	public byte getId() {
		return (byte)7;
	}

	public String toString() {
		return "[" + this.data.length + " bytes]";
	}

	public NBTBase copy() {
		byte[] data = new byte[this.data.length];
		System.arraycopy(this.data, 0, data, 0, this.data.length);
		return new NBTTagByteArray(data);
	}

	public boolean equals(Object other) {
		return super.equals(other) && Arrays.equals(this.data, ((NBTTagByteArray)other).data);
	}

	public int hashCode() {
		return super.hashCode() ^ Arrays.hashCode(this.data);
	}

	public byte[] getByteArray() {
		return this.data;
	}
}
