package common.nbt;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Arrays;

class NBTTagIntArray extends NBTBase {
	private int[] data;

	NBTTagIntArray() {
	}

	public NBTTagIntArray(int[] data) {
		this.data = data;
	}

	void write(DataOutput output) throws IOException {
		output.writeInt(this.data.length);
		for(int i = 0; i < this.data.length; ++i) {
			output.writeInt(this.data[i]);
		}
	}

	void read(DataInput input, int depth, SizeTracker tracker) throws IOException {
		tracker.read(24);
		int len = input.readInt();
		tracker.read(4 * len);
		this.data = new int[len];
		for(int z = 0; z < len; z++) {
			this.data[z] = input.readInt();
		}
	}

	public byte getId() {
		return (byte)11;
	}

	public String toString() {
		StringBuilder sb = new StringBuilder("[");
		for(int i : this.data) {
			sb.append(i + ",");
		}
		return sb.append("]").toString();
	}

	public NBTBase copy() {
		int[] data = new int[this.data.length];
		System.arraycopy(this.data, 0, data, 0, this.data.length);
		return new NBTTagIntArray(data);
	}

	public boolean equals(Object other) {
		return super.equals(other) && Arrays.equals(this.data, ((NBTTagIntArray)other).data);
	}

	public int hashCode() {
		return super.hashCode() ^ Arrays.hashCode(this.data);
	}

	public int[] getIntArray() {
		return this.data;
	}
}
